/// <reference types="react" />
declare type Props = {
    Component?: React.ReactElement;
};
declare const OAuthPopup: (props: Props) => JSX.Element;

declare type AuthTokenPayload = {
    token_type: string;
    expires_in: number;
    access_token: string;
    scope: string;
    refresh_token: string;
};
declare type ResponseTypeBasedProps<TData> = {
    responseType: 'code';
    exchangeCodeForTokenServerURL: string;
    exchangeCodeForTokenMethod?: 'POST' | 'GET';
    onSuccess?: (payload: TData) => void;
} | {
    responseType: 'token';
    onSuccess?: (payload: TData) => void;
};
declare type Oauth2Props<TData = AuthTokenPayload> = {
    authorizeUrl: string;
    clientId: string;
    redirectUri: string;
    scope?: string;
    extraQueryParameters?: Record<string, any>;
    onError?: (error: string) => void;
} & ResponseTypeBasedProps<TData>;
declare type State<TData = AuthTokenPayload> = TData | null;
declare const useOAuth2: <TData = AuthTokenPayload>(props: Oauth2Props<TData>) => {
    data: State<AuthTokenPayload>;
    loading: boolean;
    error: null;
    getAuth: () => () => void;
};

export { OAuthPopup, useOAuth2 };
